-- -----------------------------
-- Think MySQL Data Transfer
-- Date : 2019-07-10 17:30:00
-- -----------------------------

SET FOREIGN_KEY_CHECKS = 0;


-- -----------------------------
-- Table structure for `onethink_action`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_action`;
CREATE TABLE `onethink_action` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` char(30) NOT NULL DEFAULT '' COMMENT '行为唯一标识',
  `title` char(80) NOT NULL DEFAULT '' COMMENT '行为说明',
  `remark` char(140) NOT NULL DEFAULT '' COMMENT '行为描述',
  `rule` text NULL  COMMENT '行为规则',
  `log` text NULL  COMMENT '日志规则',
  `type` tinyint(2) unsigned NOT NULL DEFAULT '1' COMMENT '类型',
  `status` tinyint(2) NOT NULL DEFAULT '0' COMMENT '状态',
  `update_time` int(11) unsigned NOT NULL DEFAULT '0' COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='系统行为表';

-- -----------------------------
-- Records of `onethink_action`
-- -----------------------------
INSERT INTO `onethink_action` (`id`, `name`, `title`, `remark`, `rule`, `log`, `type`, `status`, `update_time`) VALUES(1, 'user_login', '用户登录', '积分+10，每天一次', 'table:member|field:score|condition:uid={$self} AND status>-1|rule:score+10|cycle:24|max:1;', '[user|get_nickname]在[time|time_format]登录了后台', 1, 1, 1387181220);
INSERT INTO `onethink_action` (`id`, `name`, `title`, `remark`, `rule`, `log`, `type`, `status`, `update_time`) VALUES(2, 'update_config', '更新配置', '新增或修改或删除配置', '', '', 1, 1, 1383294988);

-- -----------------------------
-- Table structure for `onethink_action_log`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_action_log`;
CREATE TABLE `onethink_action_log` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '主键',
  `action_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '行为id',
  `user_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '执行用户id',
  `action_ip` bigint(20) NOT NULL COMMENT '执行行为者ip',
  `model` varchar(50) NOT NULL DEFAULT '' COMMENT '触发行为的表',
  `record_id` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '触发行为的数据id',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '日志备注',
  `status` tinyint(2) NOT NULL DEFAULT '1' COMMENT '状态',
  `create_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '执行行为的时间',
  PRIMARY KEY (`id`),
  KEY `action_ip_ix` (`action_ip`),
  KEY `action_id_ix` (`action_id`),
  KEY `user_id_ix` (`user_id`)
) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=FIXED COMMENT='行为日志表';

-- -----------------------------
-- Table structure for `onethink_auth_group`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_auth_group`;
CREATE TABLE `onethink_auth_group` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '用户组id,自增主键',
  `module` varchar(20) NOT NULL DEFAULT '' COMMENT '用户组所属模块',
  `type` tinyint(4) NOT NULL DEFAULT '0' COMMENT '组类型',
  `title` char(20) NOT NULL DEFAULT '' COMMENT '用户组中文名称',
  `description` varchar(80) NOT NULL DEFAULT '' COMMENT '描述信息',
  `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '用户组状态：为1正常，为0禁用,-1为删除',
  `rules` varchar(500) NOT NULL DEFAULT '' COMMENT '用户组拥有的规则id，多个规则 , 隔开',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;

-- -----------------------------
-- Records of `onethink_auth_group`
-- -----------------------------

-- -----------------------------
-- Table structure for `onethink_auth_group_access`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_auth_group_access`;
CREATE TABLE `onethink_auth_group_access` (
  `uid` int(10) unsigned NOT NULL COMMENT '用户id',
  `group_id` mediumint(8) unsigned NOT NULL COMMENT '用户组id',
  UNIQUE KEY `uid_group_id` (`uid`,`group_id`),
  KEY `uid` (`uid`),
  KEY `group_id` (`group_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;


-- -----------------------------
-- Table structure for `onethink_auth_rule`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_auth_rule`;
CREATE TABLE `onethink_auth_rule` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '规则id,自增主键',
  `module` varchar(20) NOT NULL COMMENT '规则所属module',
  `type` tinyint(2) NOT NULL DEFAULT '1' COMMENT '1-url;2-主菜单',
  `name` char(80) NOT NULL DEFAULT '' COMMENT '规则唯一英文标识',
  `title` char(20) NOT NULL DEFAULT '' COMMENT '规则中文描述',
  `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '是否有效(0:无效,1:有效)',
  `condition` varchar(300) NOT NULL DEFAULT '' COMMENT '规则附加条件',
  PRIMARY KEY (`id`),
  KEY `module` (`module`,`status`,`type`)
) ENGINE=MyISAM AUTO_INCREMENT=217 DEFAULT CHARSET=utf8;


INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(1, 'admin', 2, 'Admin/Index/index', '首页', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(2, 'admin', 1, 'Admin/User/add', '新增用户', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(3, 'admin', 1, 'Admin/user/index', '用户管理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(4, 'admin', 1, 'Admin/User/changeStatus?method=resumeUser', '启用会员', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(5, 'admin', 1, 'Admin/User/changeStatus?method=forbidUser', '禁用会员', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(6, 'admin', 1, 'Admin/User/changeStatus?method=deleteUser', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(7, 'admin', 2, 'Admin/User/index', '用户', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(8, 'admin', 1, 'Admin/AuthManager/auth_list', '用户组', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(9, 'admin', 1, 'Admin/AuthManager/writeGroup', '新增/编辑', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(10, 'admin', 1, 'Admin/AuthManager/changeStatus?method=deleteGroup', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(11, 'admin', 1, 'Admin/AuthManager/btGroup', '访问授权', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(12, 'admin', 1, 'Admin/AuthManager/auth_act', '保存信息', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(13, 'admin', 1, 'Admin/AuthManager/delGroupUser', '取消', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(14, 'admin', 1, 'Admin/AuthManager/addToGroup', '增加', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(15, 'admin', 1, 'Admin/AuthManager/user_group', '用户授权', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(16, 'admin', 1, 'Admin/AuthManager/act_add', '新增/编辑', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(17, 'admin', 1, 'Admin/Ftp/AddUser', '新增', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(18, 'admin', 1, 'Admin/Ftp/index', 'FTP管理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(19, 'admin', 1, 'Admin/database/index', '数据库管理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(20, 'admin', 1, 'Admin/database/AddDatabase', '新增', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(21, 'admin', 1, 'Admin/database/ReTable', '修复', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(22, 'admin', 1, 'Admin/database/SetDatabaseAccess', '设置权限', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(23, 'admin', 1, 'Admin/database/DeleteDatabase', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(24, 'admin', 1, 'Admin/database/SetupPassword', '改root密码', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(25, 'admin', 1, 'Admin/AuthManager/act_order', '排序', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(26, 'admin', 2, 'Admin/Ftp/index', 'FTP', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(27, 'admin', 1, 'Admin/ftp/SetStatus?status=0', '禁用', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(28, 'admin', 1, 'Admin/database/ToBackup', '备份', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(29, 'admin', 1, 'Admin/database/OpTable', '优化', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(30, 'admin', 1, 'Admin/database/GetDatabaseAccess', '权限', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(31, 'admin', 1, 'Admin/database/ResDatabasePassword', '修改密码', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(32, 'admin', 1, 'Admin/ftp/SetStatus?status=1', '启用', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(33, 'admin', 2, 'Admin/database/index', '数据库', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(34, 'admin', 1, 'Admin/database/DelBackup', '删除备份', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(35, 'admin', 1, 'Admin/database/GetInfo', '工具', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(36, 'admin', 1, 'Admin/database/AlTable', '转换存储引擎', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(37, 'admin', 1, 'Admin/ftp/SetUserPassword', '改密', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(38, 'admin', 1, 'Admin/database/InputSql', '备份恢复', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(39, 'admin', 1, 'Admin/AuthManager/act_list', '操作管理', -1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(40, 'admin', 1, 'Admin/ftp/DeleteUser', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(41, 'admin', 1, 'Admin/ftp/setPort', '修改端口(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(42, 'admin', 1, 'Admin/writeGroup?act=add', '新增', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(43, 'admin', 1, 'Admin/writeGroup?act=edit', '编辑', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(44, 'admin', 1, 'Admin/AuthManager/groupList', '用户组', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(45, 'admin', 1, 'Admin/AuthManager/groupActSave', '保存信息', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(46, 'admin', 1, 'Admin/AuthManager/groupAct', '访问授权', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(47, 'admin', 1, 'Admin/AuthManager/actAdd', '新增', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(48, 'admin', 1, 'Admin/AuthManager/actDel', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(49, 'admin', 1, 'Admin/AuthManager/actAdd?act=edit', '编辑', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(50, 'admin', 1, 'Admin/AuthManager/userGroup', '用户授权', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(51, 'admin', 1, 'Admin/AuthManager/actOrder', '排序', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(52, 'admin', 1, 'Admin/AuthManager/actList', '操作管理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(53, 'admin', 2, 'Admin/site/index', '网站', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(54, 'admin', 1, 'Admin/site/get_site_types', '网站分类', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(55, 'admin', 1, 'Admin/site/add_site_type', '添加分类', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(56, 'admin', 1, 'Admin/site/modify_site_type_name', '修改分类', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(57, 'admin', 1, 'Admin/site/remove_site_type', '删除分类', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(58, 'admin', 1, 'Admin/site/set_site_type', '设置网站分类', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(59, 'admin', 1, 'Admin/site/index', '网站管理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(60, 'admin', 1, 'Admin/site/AddSite', '新增网站', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(61, 'admin', 1, 'Admin/site/AddDirBinding', '添加子目录绑定', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(62, 'admin', 1, 'Admin/site/SetDirUserINI', '防跨站攻击(请禁止)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(63, 'admin', 1, 'Admin/site/GetLimitNet', '流量限制', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(64, 'admin', 1, 'Admin/site/SetLimitNet', '启用流量控制', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(65, 'admin', 1, 'Admin/site/CloseLimitNet', '关闭流量控制', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(66, 'admin', 1, 'Admin/site/GetRewriteList', '设置伪静态', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(67, 'admin', 1, 'Admin/site/SetRewriteTel', '保存伪静态模板', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(68, 'admin', 1, 'Admin/site/SiteStart', '启动', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(69, 'admin', 1, 'Admin/site/DelDirBinding', '删除子目录绑定', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(70, 'admin', 1, 'Admin/site/logsOpen', '写访问日志', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(71, 'admin', 1, 'Admin/site/SiteStop', '停止', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(72, 'admin', 1, 'Admin/site/GetDirUserINI', '网站目录', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(73, 'admin', 1, 'Admin/site/SetSiteRunPath', '运行目录', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(74, 'admin', 1, 'Admin/site/DeleteSite', '删除', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(75, 'admin', 1, 'Admin/site/GetDirBinding', '子目录绑定', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(76, 'admin', 1, 'Admin/site/GetDirRewrite', '子目录伪静态', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(77, 'admin', 1, 'Admin/site/SetHasPwd', '密码访问', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(78, 'admin', 1, 'Admin/site/SetEdate', '到期时间', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(79, 'admin', 1, 'Admin/site/CloseHasPwd', '关闭密码访问', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(80, 'admin', 1, 'Admin/site/AddDomain', '添加域名', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(81, 'admin', 1, 'Admin/site/DelDomain', '删除域名', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(82, 'admin', 1, 'Admin/site/SetIndex', '保存默认文档', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(83, 'admin', 1, 'Admin/site/GetSiteLogs', '响应日志', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(84, 'admin', 1, 'Admin/site/GetIndex', '默认文档', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(85, 'admin', 1, 'Admin/files/GetFileBody?checkRule=get_site_config', '配置文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(86, 'admin', 1, 'Admin/files/SaveFileBody?checkRule=set_site_config', '保存配置文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(87, 'admin', 1, 'Admin/site/SetPHPVersion', '设置PHP版本', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(88, 'admin', 1, 'Admin/site/CreateRed', '添加重定向', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(89, 'admin', 1, 'Admin/site/SaveRedirectFile', '编辑重定向配置文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(90, 'admin', 1, 'Admin/site/GetSitePHPVersion', 'PHP版本', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(91, 'admin', 1, 'Admin/site/ModifyRedirect', '编辑重定向', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(92, 'admin', 1, 'Admin/site/DeleteRedirect', '删除重定向', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(93, 'admin', 1, 'Admin/site/GetRedirectList', '重定向', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(94, 'admin', 1, 'Admin/site/CreateProxy', '添加反向代理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(95, 'admin', 1, 'Admin/site/SaveProxyFile', '保存反向代理配置文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(96, 'admin', 1, 'Admin/site/SetSecurity', '防盗链设置', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(97, 'admin', 1, 'Admin/site/SetDefaultSite', '设置默认站点(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(98, 'admin', 1, 'Admin/files/SaveFileBody?checkRule=default_doc', '默认文档(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(99, 'admin', 1, 'Admin/files/index', '文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(100, 'admin', 1, 'Admin/files/CreateFile', '创建文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(101, 'admin', 1, 'Admin/files/CreateDir', '创建目录', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(102, 'admin', 1, 'Admin/files/DeleteFile', '删除文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(103, 'admin', 1, 'Admin/files/DeleteDir', '删除目录', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(104, 'admin', 1, 'Admin/files/SetFileAccess', '设置文件权限', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(105, 'admin', 1, 'Admin/files/upload', '上传', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(106, 'admin', 1, 'Admin/files/CopyFile', '复制&amp;粘贴', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(107, 'admin', 1, 'Admin/files/MvFile', '剪切&amp;粘贴', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(108, 'admin', 1, 'Admin/files/Zip', '压缩', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(109, 'admin', 1, 'Admin/files/UnZip', '解压', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(110, 'admin', 1, 'Admin/site/RemoveProxy', '删除反向代理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(111, 'admin', 1, 'Admin/files/SaveFileBody?checkRule=err_404', '404错误页(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(112, 'admin', 1, 'Admin/site/ModifyProxy', '编辑反向代理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(113, 'admin', 1, 'Admin/files/SaveFileBody?checkRule=empty_page', '空白页(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(114, 'admin', 1, 'Admin/site/GetDefaultSite', '默认站点(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(115, 'admin', 1, 'Admin/files/SaveFileBody?checkRule=default_page_stop', '默认站点停止页(全局)', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(116, 'admin', 2, 'Admin/files/index', '文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(117, 'admin', 1, 'Admin/site/GetProxyList', '反向代理', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(118, 'admin', 1, 'Admin/site/GetProxyFile', '反向代理配置文件', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(119, 'admin', 1, 'Admin/site/GetSecurity', '防盗链', 1, '');
INSERT INTO `onethink_auth_rule` (`id`, `module`, `type`, `name`, `title`, `status`, `condition`) VALUES(120, 'admin', 1, 'Admin//', '默认页(全局)', 1, '');


-- -----------------------------
-- Table structure for `onethink_config`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_config`;
CREATE TABLE `onethink_config` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '配置ID',
  `name` varchar(30) NOT NULL DEFAULT '' COMMENT '配置名称',
  `type` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '配置类型',
  `title` varchar(50) NOT NULL DEFAULT '' COMMENT '配置说明',
  `group` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '配置分组',
  `extra` varchar(255) NOT NULL DEFAULT '' COMMENT '配置值',
  `remark` varchar(100) NOT NULL DEFAULT '' COMMENT '配置说明',
  `create_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '创建时间',
  `update_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '更新时间',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '状态',
  `value` text NULL  COMMENT '配置值',
  `sort` smallint(3) unsigned NOT NULL DEFAULT '0' COMMENT '排序',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_name` (`name`),
  KEY `type` (`type`),
  KEY `group` (`group`)
) ENGINE=MyISAM AUTO_INCREMENT=38 DEFAULT CHARSET=utf8;

INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(1, 'CONFIG_TYPE_LIST', 3, '配置类型列表', 1, '', '主要用于数据解析和页面表单的生成', 1378898976, 1379235348, 1, '0:数字\r\n1:字符\r\n2:文本\r\n3:数组\r\n4:枚举', 2);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(2, 'CONFIG_GROUP_LIST', 3, '配置分组', 1, '', '配置分组', 1379228036, 1384418383, 1, '1:基本\r\n2:内容\r\n3:用户\r\n4:系统', 4);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(3, 'AUTH_CONFIG', 3, 'Auth配置', 1, '', '自定义Auth.class.php类配置', 1379409310, 1379409564, 1, 'AUTH_ON:1\r\nAUTH_TYPE:2', 8);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(4, 'ALLOW_VISIT', 3, '不受限控制器方法', 1, '', '', 1386644047, 1562211654, 1, '0:index/index\r\n1:article/mydocument\r\n2:Category/tree\r\n3:Index/verify\r\n4:file/upload\r\n5:file/download\r\n6:user/updatePassword\r\n7:user/updateNickname\r\n8:user/submitPassword\r\n9:user/submitNickname\r\n10:file/uploadpicture\r\n11:ajax/GetTaskCount\r\n12:ajax/CheckInstalled\r\n13:system/GetNetWork\r\n14:system/GetSystemTotal\r\n15:system/GetDiskInfo\r\n16:task/get_task_lists\r\n17:config/GetPanelList\r\n18:config/get_config\r\n19:plugin/get_index_list\r\n20:plugin/getConfigHtml\r\n21:data/getData\r\n22:data/setPs\r\n23:data/getKey\r\n24:files/upload\r\n25:site/get_site_types\r\n26:site/GetPHPVersion\r\n27:files/GetFileBody\r\n28:files/SaveFileBody\r\n29:files/CheckExistsFiles\r\n30:files/GetDir\r\n31:files/GetFileAccess\r\n32:files/GetDirSize\r\n33:files/get_path_size', 0);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(5, 'DENY_VISIT', 3, '超管专限控制器方法', 1, '', '仅超级管理员可访问的控制器方法', 1386644141, 1386644659, 1, '0:Addons/addhook\r\n1:Addons/edithook\r\n2:Addons/delhook\r\n3:Addons/updateHook\r\n4:Admin/getMenus\r\n5:Admin/recordList\r\n6:AuthManager/updateRules\r\n7:AuthManager/tree', 0);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(6, 'BT_PANEL', 1, '面板地址', 1, '', '', 1561451538, 1561800563, 1, '', 0);
INSERT INTO `onethink_config` (`id`, `name`, `type`, `title`, `group`, `extra`, `remark`, `create_time`, `update_time`, `status`, `value`, `sort`) VALUES(7, 'BT_KEY', 1, 'BT_KEY', 1, '', '', 1561451596, 1561817364, 1, '', 0);

-- -----------------------------
-- Table structure for `onethink_member`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_member`;
CREATE TABLE `onethink_member` (
  `uid` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '用户ID',
  `nickname` char(16) NOT NULL DEFAULT '' COMMENT '昵称',
  `sex` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '性别',
  `birthday` date NOT NULL DEFAULT '0000-00-00' COMMENT '生日',
  `qq` char(10) NOT NULL DEFAULT '' COMMENT 'qq号',
  `score` mediumint(8) NOT NULL DEFAULT '0' COMMENT '用户积分',
  `login` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '登录次数',
  `reg_ip` bigint(20) NOT NULL DEFAULT '0' COMMENT '注册IP',
  `reg_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '注册时间',
  `last_login_ip` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后登录IP',
  `last_login_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '最后登录时间',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '会员状态',
  PRIMARY KEY (`uid`),
  KEY `status` (`status`)
) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='会员表';

-- -----------------------------
-- Table structure for `onethink_menu`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_menu`;
CREATE TABLE `onethink_menu` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '文档ID',
  `title` varchar(50) NOT NULL DEFAULT '' COMMENT '标题',
  `pid` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '上级分类ID',
  `sort` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '排序（同级有效）',
  `url` char(255) NOT NULL DEFAULT '' COMMENT '链接地址',
  `hide` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '是否隐藏',
  `tip` varchar(255) NOT NULL DEFAULT '' COMMENT '提示',
  `group` varchar(50) DEFAULT '' COMMENT '分组',
  `is_dev` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT '是否仅开发者模式可见',
  `status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '状态',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`),
  KEY `status` (`status`)
) ENGINE=MyISAM AUTO_INCREMENT=122 DEFAULT CHARSET=utf8;

INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(1, '首页', 0, 0, 'Index/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(2, '用户', 0, 5, 'User/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(3, '新增用户', 4, 0, 'User/add', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(4, '用户管理', 2, 0, 'user/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(5, '启用会员', 4, 1, 'User/changeStatus?method=resumeUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(6, '禁用会员', 4, 2, 'User/changeStatus?method=forbidUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(7, '删除', 4, 3, 'User/changeStatus?method=deleteUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(8, '用户组', 2, 1, 'AuthManager/groupList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(9, '新增', 8, 0, 'writeGroup?act=add', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(10, '删除', 8, 2, 'AuthManager/changeStatus?method=deleteGroup', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(11, '访问授权', 2, 3, 'AuthManager/groupAct', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(12, '保存信息', 11, 0, 'AuthManager/groupActSave', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(13, '取消', 14, 0, 'AuthManager/delGroupUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(14, '用户授权', 2, 2, 'AuthManager/userGroup', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(15, '增加', 14, 1, 'AuthManager/addToGroup', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(16, '操作管理', 2, 4, 'AuthManager/actList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(17, '新增', 16, 0, 'AuthManager/actAdd', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(18, '排序', 16, 3, 'AuthManager/actOrder', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(19, 'FTP', 0, 2, 'Ftp/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(20, '新增', 21, 0, 'Ftp/AddUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(21, 'FTP管理', 19, 0, 'Ftp/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(22, '禁用', 21, 1, 'ftp/SetStatus?status=0', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(23, '启用', 21, 2, 'ftp/SetStatus?status=1', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(24, '改密', 21, 3, 'ftp/SetUserPassword', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(25, '删除', 21, 4, 'ftp/DeleteUser', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(26, '修改端口(全局)', 21, 5, 'ftp/setPort', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(27, '数据库', 0, 3, 'database/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(28, '数据库管理', 27, 0, 'database/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(29, '新增', 28, 0, 'database/AddDatabase', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(30, '备份', 28, 1, 'database/ToBackup', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(31, '删除备份', 28, 2, 'database/DelBackup', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(32, '备份恢复', 28, 3, 'database/InputSql', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(33, '工具', 27, 2, 'database/GetInfo', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(34, '修复', 33, 0, 'database/ReTable', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(35, '优化', 33, 1, 'database/OpTable', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(36, '转换存储引擎', 33, 2, 'database/AlTable', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(37, '权限', 27, 1, 'database/GetDatabaseAccess', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(38, '修改密码', 37, 3, 'database/ResDatabasePassword', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(39, '设置权限', 37, 0, 'database/SetDatabaseAccess', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(40, '删除', 37, 1, 'database/DeleteDatabase', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(41, '改root密码', 37, 2, 'database/SetupPassword', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(43, '编辑', 16, 2, 'AuthManager/actAdd?act=edit', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(42, '编辑', 8, 1, 'writeGroup?act=edit', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(44, '删除', 16, 1, 'AuthManager/actDel', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(46, '网站', 0, 1, 'site/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(47, '网站分类', 46, 0, 'site/get_site_types', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(48, '添加分类', 47, 0, 'site/add_site_type', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(49, '修改分类', 47, 1, 'site/modify_site_type_name', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(50, '删除分类', 47, 2, 'site/remove_site_type', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(51, '设置网站分类', 47, 3, 'site/set_site_type', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(52, '网站管理', 46, 1, 'site/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(53, '新增网站', 52, 0, 'site/AddSite', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(54, '启动', 52, 1, 'site/SiteStart', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(55, '停止', 52, 2, 'site/SiteStop', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(56, '删除', 52, 3, 'site/DeleteSite', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(57, '到期时间', 52, 4, 'site/SetEdate', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(58, '添加域名', 52, 5, 'site/AddDomain', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(59, '删除域名', 52, 6, 'site/DelDomain', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(60, '子目录绑定', 46, 4, 'site/GetDirBinding', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(61, '添加子目录绑定', 60, 0, 'site/AddDirBinding', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(62, '删除子目录绑定', 60, 1, 'site/DelDirBinding', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(64, '子目录伪静态', 60, 2, 'site/GetDirRewrite', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(65, '网站目录', 46, 3, 'site/GetDirUserINI', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(66, '防跨站攻击(请禁止)', 65, 0, 'site/SetDirUserINI', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(76, '响应日志', 65, 2, 'site/GetSiteLogs', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(67, '写访问日志', 65, 1, 'site/logsOpen', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(68, '运行目录', 65, 3, 'site/SetSiteRunPath', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(69, '密码访问', 65, 4, 'site/SetHasPwd', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(70, '关闭密码访问', 65, 5, 'site/CloseHasPwd', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(71, '流量限制', 46, 5, 'site/GetLimitNet', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(72, '启用流量控制', 71, 0, 'site/SetLimitNet', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(73, '关闭流量控制', 71, 1, 'site/CloseLimitNet', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(74, '设置伪静态', 52, 7, 'site/GetRewriteList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(75, '保存伪静态模板', 52, 8, 'site/SetRewriteTel', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(77, '默认文档', 46, 6, 'site/GetIndex', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(78, '保存默认文档', 77, 0, 'site/SetIndex', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(79, '配置文件', 46, 7, 'files/GetFileBody?checkRule=get_site_config', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(80, '保存配置文件', 79, 0, 'files/SaveFileBody?checkRule=set_site_config', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(81, 'PHP版本', 46, 2, 'site/GetSitePHPVersion', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(82, '设置PHP版本', 81, 0, 'site/SetPHPVersion', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(83, '重定向', 46, 8, 'site/GetRedirectList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(84, '添加重定向', 83, 0, 'site/CreateRed', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(85, '编辑重定向', 83, 1, 'site/ModifyRedirect', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(86, '删除重定向', 83, 2, 'site/DeleteRedirect', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(87, '查看重定向配置文件', 83, 3, 'site/GetRedirectList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(88, '编辑重定向配置文件', 83, 4, 'site/SaveRedirectFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(89, '反向代理', 46, 9, 'site/GetProxyList', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(90, '添加反向代理', 89, 0, 'site/CreateProxy', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(91, '编辑反向代理', 89, 2, 'site/ModifyProxy', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(92, '反向代理配置文件', 46, 10, 'site/GetProxyFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(93, '保存反向代理配置文件', 92, 0, 'site/SaveProxyFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(94, '删除反向代理', 89, 1, 'site/RemoveProxy', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(95, '防盗链', 46, 11, 'site/GetSecurity', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(96, '防盗链设置', 95, 0, 'site/SetSecurity', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(97, '默认站点(全局)', 27, 3, 'site/GetDefaultSite', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(98, '设置默认站点(全局)', 97, 0, 'site/SetDefaultSite', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(99, '默认页(全局)', 46, 12, '/', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(100, '默认文档(全局)', 99, 0, 'files/SaveFileBody?checkRule=default_doc', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(101, '404错误页(全局)', 99, 1, 'files/SaveFileBody?checkRule=err_404', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(102, '空白页(全局)', 99, 2, 'files/SaveFileBody?checkRule=empty_page', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(103, '默认站点停止页(全局)', 99, 3, 'files/SaveFileBody?checkRule=default_page_stop', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(104, '文件', 0, 4, 'files/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(105, '文件', 104, 0, 'files/index', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(106, '创建文件', 105, 0, 'files/CreateFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(107, '创建目录', 105, 1, 'files/CreateDir', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(108, '删除文件', 105, 2, 'files/DeleteFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(109, '删除目录', 105, 3, 'files/DeleteDir', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(110, '设置文件权限', 105, 4, 'files/SetFileAccess', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(111, '上传', 105, 5, 'files/upload', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(112, '复制&amp;粘贴', 105, 6, 'files/CopyFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(113, '剪切&amp;粘贴', 105, 7, 'files/MvFile', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(114, '压缩', 105, 8, 'files/Zip', 0, '', '', 0, 1);
INSERT INTO `onethink_menu` (`id`, `title`, `pid`, `sort`, `url`, `hide`, `tip`, `group`, `is_dev`, `status`) VALUES(115, '解压', 105, 9, 'files/UnZip', 0, '', '', 0, 1);

-- -----------------------------
-- Table structure for `onethink_model`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_model`;
CREATE TABLE `onethink_model` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '模型ID',
  `name` char(30) NOT NULL DEFAULT '' COMMENT '模型标识',
  `title` char(30) NOT NULL DEFAULT '' COMMENT '模型名称',
  `extend` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '继承的模型',
  `relation` varchar(30) NOT NULL DEFAULT '' COMMENT '继承与被继承模型的关联字段',
  `need_pk` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '新建表时是否需要主键字段',
  `field_sort` text NULL  COMMENT '表单字段排序',
  `field_group` varchar(255) NOT NULL DEFAULT '1:基础' COMMENT '字段分组',
  `attribute_list` text NULL  COMMENT '属性列表（表的字段）',
  `attribute_alias` varchar(255) NOT NULL DEFAULT '' COMMENT '属性别名定义',
  `template_list` varchar(100) NOT NULL DEFAULT '' COMMENT '列表模板',
  `template_add` varchar(100) NOT NULL DEFAULT '' COMMENT '新增模板',
  `template_edit` varchar(100) NOT NULL DEFAULT '' COMMENT '编辑模板',
  `list_grid` text NULL  COMMENT '列表定义',
  `list_row` smallint(2) unsigned NOT NULL DEFAULT '10' COMMENT '列表数据长度',
  `search_key` varchar(50) NOT NULL DEFAULT '' COMMENT '默认搜索字段',
  `search_list` varchar(255) NOT NULL DEFAULT '' COMMENT '高级搜索的字段',
  `create_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '创建时间',
  `update_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '更新时间',
  `status` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '状态',
  `engine_type` varchar(25) NOT NULL DEFAULT 'MyISAM' COMMENT '数据库引擎',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COMMENT='文档模型表';




-- -----------------------------
-- Table structure for `onethink_ucenter_member`
-- -----------------------------
DROP TABLE IF EXISTS `onethink_ucenter_member`;
CREATE TABLE `onethink_ucenter_member` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '用户ID',
  `username` char(16) NOT NULL COMMENT '用户名',
  `password` char(32) NOT NULL COMMENT '密码',
  `email` char(32) NOT NULL COMMENT '用户邮箱',
  `mobile` char(15) NOT NULL DEFAULT '' COMMENT '用户手机',
  `reg_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '注册时间',
  `reg_ip` bigint(20) NOT NULL DEFAULT '0' COMMENT '注册IP',
  `last_login_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '最后登录时间',
  `last_login_ip` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后登录IP',
  `update_time` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '更新时间',
  `status` tinyint(4) DEFAULT '0' COMMENT '用户状态',
  PRIMARY KEY (`id`),
  UNIQUE KEY `username` (`username`),
  UNIQUE KEY `email` (`email`),
  KEY `status` (`status`)
) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='用户表';


